@@ -16,6 +16,9 @@ public:
     explicit WNew(QWidget *parent = 0);
     ~WNew();
 
+public slots:
+    void reorderUI();
+
 private slots:
     void on_btnEyesRight_pressed();
     void on_btnEyesRight_clicked();
@@ -41,6 +44,8 @@ private slots:
     void on_btnMouthRight_clicked();
     void on_btnMouthRight_released();
 
+    void on_btnSave_clicked();
+
 private:
     Ui::WNew *ui;
 
